==> arirang-2.01.tar.gz: arirang-2.01/arirang.h <==
/*
* Copyright 2001-2002, 2010 pilot <pilot@monkey.org>
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
* 1. Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
* 2. Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the distribution.
* 3. The name of the author may not be used to endorse or promote products
*    derived from this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
* IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
* OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
* NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
* THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/* arirang header file */
#ifndef _ARIRANG_H_
#define _ARIRANG_H_ 

#include <openssl/ssl.h>
#include <openssl/err.h>

#define TITLE   "powerful webserver security scanner for network"
#define HOMEPAGE    "http://www.monkey.org/~pilot/arirang/"

#define PATH_CLEAR  "/usr/bin/clear"

#define NETCRAFT    "uptime.netcraft.com"
#define NETCRAFT_FINGER "/up/graph/?site="
#define HTML_FILTER "<>b"
#define WAIT_TIME 5

#define SEND_URI    "GET / HTTP/1.0\r\n\r\n"
#define SEND_OPTION "OPTIONS / HTTP/1.0\r\n\r\n"
#define HTTP_VER_1  " HTTP/1.0"
#define HTTP_VER_1_1    " HTTP/1.1"

#define USED_IP_RANGE   "/tmp/ip_range.arirang"

#define SCANRULE_MSG   "arirang scanrule"

/* script 
struct script {
    TAILQ_ENTRY(script) next;
    char *name;
};
*/
void scanrule(char *, unsigned int, char *, unsigned short int);
void scanruleP(char *, unsigned int, char *, unsigned short int, unsigned short int);

int recvtimeout(int, char *, int, int);
int recvtimeoutr(int, char *, int, int, int);

void grabhead(char *, unsigned int, short int);
void grabheadW(unsigned long, unsigned int, unsigned short int, short int);
void osdetect(char *);
void scrview(void);
void usage(void);

void timegrab(int );   
void connout(int );
void sslconnout(int sig);

void htmlhead(char *);
/* use html functions in the future */
void htmlbody(FILE *);
void htmlrequest(FILE *);
void htmlreponse(FILE *);
void htmlurl(FILE *);
void htmlexplain(FILE *);
void htmlinfo(FILE *);
void htmlstyle(FILE *);
void htmltail(char *);
void htmllink(FILE *);
void htmlframe(FILE *);
void htmlcss(FILE *);
void htmlserver(FILE *);


SSL_CTX *ssl_init_ctx(void);
SSL *ssl_init_ssl(SSL_CTX *, int);
void ssl_free(SSL_CTX *, SSL *);
int ssl_read_timeout(int, SSL *, char *, int, int);
int ssl_write_timeout(int, SSL *, char *, int, int);
void ssl_error(SSL *, int, char *); 

void connout_r(int );
int recvtimeout_r(int, char *, int, int);
void ariruby_init(char *);
void ariruby_run(void);
void ariruby_exit(void);
void rubyscan(char *, unsigned int, short int);
void rubyscanW(unsigned long, unsigned int, unsigned short int, short int);

int proxy_connect(char *, unsigned int, char *, unsigned int, int);

#endif /* _ARIRANG_H_ */

==> arirang-2.02.tar.gz: arirang-2.02/arirang.h <==
/*
* Copyright 2001-2002, 2010, 2011 pilot <pilot@monkey.org>
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
* 1. Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
* 2. Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the distribution.
* 3. The name of the author may not be used to endorse or promote products
*    derived from this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
* IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
* OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
* NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
* THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
* THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/* arirang header file */
#ifndef _ARIRANG_H_
#define _ARIRANG_H_ 

#include <sys/queue.h>
#include <openssl/ssl.h>
#include <openssl/err.h>

#define TITLE   "powerful webserver security scanner for network"
#define HOMEPAGE    "http://www.monkey.org/~pilot/arirang/"

#define PATH_CLEAR  "/usr/bin/clear"

#define NETCRAFT    "uptime.netcraft.com"
#define NETCRAFT_FINGER "/up/graph/?site="
#define HTML_FILTER "<>b"
#define WAIT_TIME 5

#define SEND_URI    "GET / HTTP/1.0\r\n\r\n"
#define SEND_OPTION "OPTIONS / HTTP/1.0\r\n\r\n"
#define HTTP_VER_1  " HTTP/1.0"
#define HTTP_VER_1_1    " HTTP/1.1"

#define USED_IP_RANGE   "/tmp/ip_range.arirang"

#define SCANRULE_MSG   "arirang scanrule"

/* script 
struct script {
    TAILQ_ENTRY(script) script_next;
    char *name;
};
*/

struct scan_port {
    TAILQ_ENTRY(scan_port) port_next;
    int port;
};

void scanrule(char *, unsigned int, char *, unsigned short int);
void scanruleP(char *, unsigned int, char *, unsigned short int, unsigned short int);

int recvtimeout(int, char *, int, int);
int recvtimeoutr(int, char *, int, int, int);

void grabhead(char *, unsigned int, short int);
void grabheadW(unsigned long, unsigned int, unsigned short int, short int);
void osdetect(char *);
void scrview(void);
void usage(void);

void timegrab(int );   
void connout(int );
void sslconnout(int sig);

void htmlhead(char *);
/* use html functions in the future */
void htmlbody(FILE *);
void htmlrequest(FILE *);
void htmlreponse(FILE *);
void htmlurl(FILE *);
void htmlexplain(FILE *);
void htmlinfo(FILE *);
void htmlstyle(FILE *);
void htmltail(char *);
void htmllink(FILE *);
void htmlframe(FILE *);
void htmlcss(FILE *);
void htmlserver(FILE *);


SSL_CTX *ssl_init_ctx(void);
SSL *ssl_init_ssl(SSL_CTX *, int);
void ssl_free(SSL_CTX *, SSL *);
int ssl_read_timeout(int, SSL *, char *, int, int);
int ssl_write_timeout(int, SSL *, char *, int, int);
void ssl_error(SSL *, int, char *); 

void connout_r(int );
int recvtimeout_r(int, char *, int, int);
void ariruby_init(char *);
void ariruby_run(void);
void ariruby_exit(void);
void rubyscan(char *, unsigned int, short int);
void rubyscanW(unsigned long, unsigned int, unsigned short int, short int);

int proxy_connect(char *, unsigned int, char *, unsigned int, int);

#endif /* _ARIRANG_H_ */
